@@ -113,7 +113,7 @@ class Geo_common:
         #### 常用变量:
         self.pro_dir = self.protocol["project_dir"]
         self.contract_number = self.series["contract_number"]
-
+        self.yaml = os.path.join(self.pro_dir,self.contract_number+'.yaml')
         ############ singularity 挂载信息
         roots= []
         self.singularity_args = ''
@@ -159,9 +159,9 @@ fi
             f.write("""
 %s/script/SuppGenerate.py --yaml %s --odir %s/Report/supp/ && \\
 
-%s/script/Report.R %s %s/Report
-"""%(self.pro_dir, yaml_file, self.pro_dir,
-    self.pipe_dir, self.pro_dir, self.pro_dir))
+%s/script/Report.R %s/Report %s
+"""%(self.pipe_dir, yaml_file, self.pro_dir,
+    self.pipe_dir, self.pro_dir, self.yaml))
 
         upload_shell = os.path.join(self.pro_dir, "upload.sh")
         oss_path = get_oss_path(self.contract_number)
