@@ -27,7 +27,7 @@ def main(args):
         remote_dest = args.remote
         if dir != ".":
             remote_dest = os.path.join(args.remote,dir)
-        file = subprocess.getoutput("readlink -f %s"(file))
+        file = subprocess.getoutput("readlink -f %s" %(file))
         os.system("BaiduPCS-Go upload %s %s" %(file,remote_dest))
 
 if __name__ == "__main__":
